# Typicons for Light Backgrounds

This theme is based on Typicons. All files are prefixed, depending on whether they are based
directly on original Typicons, redesigned, or designed from scratch.

## Typicons Icons

The files have a `typ_` prefix. These are colourised and rescaled Typicons, but with no other
modifications.

Copyright: Stephen Hutchings  
Source: https://github.com/stephenhutchings/typicons.font  
License: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/)  

## Original Icons

The files have a `nw_` prefix. These are made completely from scratch for novelWriter and are not
using any design elements from Typicons.

Copyright: Veronica Berglyd Olsen  
License: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/)  

## Mixed Icons

The files have a `mixed_` prefix. These are redesigned from Typicons components, modified from
Typicons, or consist of a mix of Typicons and new elements.

Copyright: Stephen Hutchings, Veronica Berglyd Olsen  
License: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/)  
